==> apache-fineract-src-1.13.0.tar.gz: apache-fineract-src-1.13.0/fineract-provider/src/main/java/org/apache/fineract/infrastructure/campaigns/email/domain/EmailCampaignStatus.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.campaigns.email.domain;

public enum EmailCampaignStatus {

    INVALID(0, "emailCampaignStatus.invalid"), //
    PENDING(100, "emailCampaignStatus.pending"), //
    ACTIVE(300, "emailCampaignStatus.active"), //
    CLOSED(600, "emailCampaignStatus.closed");

    private final Integer value;
    private final String code;

    EmailCampaignStatus(Integer value, String code) {
        this.value = value;
        this.code = code;
    }

    public static EmailCampaignStatus fromInt(final Integer statusValue) {

        EmailCampaignStatus enumeration = EmailCampaignStatus.INVALID;
        switch (statusValue) {
            case 100:
                enumeration = EmailCampaignStatus.PENDING;
            break;
            case 300:
                enumeration = EmailCampaignStatus.ACTIVE;
            break;
            case 600:
                enumeration = EmailCampaignStatus.CLOSED;
            break;
        }
        return enumeration;
    }

    public Integer getValue() {
        return value;
    }

    public String getCode() {
        return code;
    }

    public boolean isActive() {
        return this.value.equals(EmailCampaignStatus.ACTIVE.getValue());
    }

    public boolean isPending() {
        return this.value.equals(EmailCampaignStatus.PENDING.getValue());
    }

    public boolean isClosed() {
        return this.value.equals(EmailCampaignStatus.CLOSED.getValue());
    }
}

==> apache-fineract-src-1.14.0.tar.gz: apache-fineract-src-1.14.0/fineract-provider/src/main/java/org/apache/fineract/infrastructure/campaigns/email/domain/EmailCampaignStatus.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.campaigns.email.domain;

public enum EmailCampaignStatus {

    INVALID(0, "emailCampaignStatus.invalid"), //
    PENDING(100, "emailCampaignStatus.pending"), //
    ACTIVE(300, "emailCampaignStatus.active"), //
    CLOSED(600, "emailCampaignStatus.closed");

    private final Integer value;
    private final String code;

    EmailCampaignStatus(Integer value, String code) {
        this.value = value;
        this.code = code;
    }

    public static EmailCampaignStatus fromInt(final Integer statusValue) {

        EmailCampaignStatus enumeration = EmailCampaignStatus.INVALID;
        enumeration = switch (statusValue) {
            case 100 -> EmailCampaignStatus.PENDING;
            case 300 -> EmailCampaignStatus.ACTIVE;
            case 600 -> EmailCampaignStatus.CLOSED;
            default -> enumeration;
        };
        return enumeration;
    }

    public Integer getValue() {
        return value;
    }

    public String getCode() {
        return code;
    }

    public boolean isActive() {
        return this.value.equals(EmailCampaignStatus.ACTIVE.getValue());
    }

    public boolean isPending() {
        return this.value.equals(EmailCampaignStatus.PENDING.getValue());
    }

    public boolean isClosed() {
        return this.value.equals(EmailCampaignStatus.CLOSED.getValue());
    }
}
